[Libreoffice-commits] core.git: ios/LibreOfficeLight

2020-08-30 Thread Andrea Gelmini (via logerrit)
 ios/LibreOfficeLight/LibreOfficeLight/DocumentController.swift   |2 +-
 ios/LibreOfficeLight/LibreOfficeLight/LOKit/DocumentHolder.swift |2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 9d007e6bdc0e1346e2e0d633379ce1f09c4e3b53
Author: Andrea Gelmini 
AuthorDate: Wed Aug 26 13:23:25 2020 +0200
Commit: Julien Nabet 
CommitDate: Mon Aug 31 08:53:59 2020 +0200

Fix typo in code

Change-Id: Ic3527d7613867656871c4ff2276b0f922d497453
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101430
Tested-by: Jenkins
Reviewed-by: Julien Nabet 
Reviewed-by: Tor Lillqvist 

diff --git a/ios/LibreOfficeLight/LibreOfficeLight/DocumentController.swift 
b/ios/LibreOfficeLight/LibreOfficeLight/DocumentController.swift
index af192249bc92..5743a1f4e7c9 100644
--- a/ios/LibreOfficeLight/LibreOfficeLight/DocumentController.swift
+++ b/ios/LibreOfficeLight/LibreOfficeLight/DocumentController.swift
@@ -422,7 +422,7 @@ class DocumentController: UIViewController, MenuDelegate, 
UIDocumentBrowserViewC
 self.documentOverlaysView = overlay
 
 // button view - used for spreadsheet tabs
-if doc.isSpeadsheet
+if doc.isSpreadsheet
 {
 buttonScrollView.isHidden = false
 buttonScrollView.setButtonLabels(labels: doc.partNames)
diff --git a/ios/LibreOfficeLight/LibreOfficeLight/LOKit/DocumentHolder.swift 
b/ios/LibreOfficeLight/LibreOfficeLight/LOKit/DocumentHolder.swift
index cfc2cb678367..9ca58eddf599 100644
--- a/ios/LibreOfficeLight/LibreOfficeLight/LOKit/DocumentHolder.swift
+++ b/ios/LibreOfficeLight/LibreOfficeLight/LOKit/DocumentHolder.swift
@@ -69,7 +69,7 @@ public class DocumentHolder
 {
 return documentType == LOK_DOCTYPE_DRAWING
 }
-public var isSpeadsheet: Bool
+public var isSpreadsheet: Bool
 {
 return documentType == LOK_DOCTYPE_SPREADSHEET
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: winaccessibility/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 winaccessibility/source/UAccCOM/AccValue.cxx |8 
 winaccessibility/source/UAccCOM/AccValue.h   |2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

New commits:
commit 912dee5178f2aec1662af284d222c591b5901add
Author: Andrea Gelmini 
AuthorDate: Fri Aug 28 13:24:56 2020 +0200
Commit: Noel Grandin 
CommitDate: Mon Aug 31 08:36:08 2020 +0200

Fix typo in code

It passed "make check" on Linux

Change-Id: Ic7796a79ebe7d600598f9c2964976cbc9408d299
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101618
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/winaccessibility/source/UAccCOM/AccValue.h 
b/winaccessibility/source/UAccCOM/AccValue.h
index b5a2ef6bba71..e16fed598b01 100644
--- a/winaccessibility/source/UAccCOM/AccValue.h
+++ b/winaccessibility/source/UAccCOM/AccValue.h
@@ -84,7 +84,7 @@ public:
 STDMETHOD(get_maximumValue)(VARIANT *maximumValue) override;
 
 // Returns the minimal value that can be represented by this object.
-STDMETHOD(get_minimumValue)(VARIANT *mininumValue) override;
+STDMETHOD(get_minimumValue)(VARIANT *minimumValue) override;
 
 // Override of IUNOXWrapper.
 STDMETHOD(put_XInterface)(hyper pXInterface) override;
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: sax/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 sax/source/expatwrap/xml2utf.cxx |   10 +-
 1 file changed, 5 insertions(+), 5 deletions(-)

New commits:
commit c0463f8a9fc4db7b62040010b3fefc9af3b17396
Author: Andrea Gelmini 
AuthorDate: Fri Aug 28 12:16:34 2020 +0200
Commit: Noel Grandin 
CommitDate: Mon Aug 31 08:34:55 2020 +0200

Fix typo in code

It passed "make check" on Linux

Change-Id: I86123dbc2052653aaf1d5c3a6fafb554c0b9a7fb
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101600
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/sax/source/expatwrap/xml2utf.cxx b/sax/source/expatwrap/xml2utf.cxx
index 9e531b13cfa6..1f044571d53d 100644
--- a/sax/source/expatwrap/xml2utf.cxx
+++ b/sax/source/expatwrap/xml2utf.cxx
@@ -160,7 +160,7 @@ void XMLFile2UTFConverter::removeEncoding( 
Sequence &seq )
 bool XMLFile2UTFConverter::isEncodingRecognizable( const Sequence< sal_Int8 > 
&seq)
 {
 const sal_Int8 *pSource = seq.getConstArray();
-bool bCheckIfFirstClosingBracketExsists = false;
+bool bCheckIfFirstClosingBracketExists = false;
 
 if( seq.getLength() < 8 ) {
 // no recognition possible, when less than 8 bytes are available
@@ -169,22 +169,22 @@ bool XMLFile2UTFConverter::isEncodingRecognizable( const 
Sequence< sal_Int8 > &s
 
 if( ! strncmp( reinterpret_cast(pSource), "') != seq.end();
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: svx/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 svx/source/gallery2/galbrws1.cxx |8 
 svx/source/gallery2/galbrws1.hxx |4 ++--
 2 files changed, 6 insertions(+), 6 deletions(-)

New commits:
commit c78449b0386ed38a2ad81584926f8b31b61e9e05
Author: Andrea Gelmini 
AuthorDate: Fri Aug 28 13:18:20 2020 +0200
Commit: Noel Grandin 
CommitDate: Mon Aug 31 08:34:39 2020 +0200

Fix typo in code

It passed "make check" on Linux

Change-Id: I1cb3b048843dc4cafa16c7f8408fc3300e5fc8e7
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101614
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/svx/source/gallery2/galbrws1.cxx b/svx/source/gallery2/galbrws1.cxx
index cb0b291b106d..366bcecbd92d 100644
--- a/svx/source/gallery2/galbrws1.cxx
+++ b/svx/source/gallery2/galbrws1.cxx
@@ -48,7 +48,7 @@ using namespace ::com::sun::star;
 GalleryBrowser1::GalleryBrowser1(
 weld::Builder& rBuilder,
 Gallery* pGallery,
-const std::function& rThemeSlectionHandler)
+const std::function& rThemeSelectionHandler)
 :
 mxNewTheme(rBuilder.weld_button("insert")),
 mxThemes(rBuilder.weld_tree_view("themelist")),
@@ -57,7 +57,7 @@ GalleryBrowser1::GalleryBrowser1(
 aImgNormal( RID_SVXBMP_THEME_NORMAL ),
 aImgDefault   ( RID_SVXBMP_THEME_DEFAULT ),
 aImgReadOnly  ( RID_SVXBMP_THEME_READONLY ),
-maThemeSlectionHandler(rThemeSlectionHandler)
+maThemeSelectionHandler(rThemeSelectionHandler)
 {
 mxNewTheme->set_help_id(HID_GALLERY_NEWTHEME);
 mxNewTheme->connect_clicked( LINK( this, GalleryBrowser1, ClickNewThemeHdl 
) );
@@ -463,8 +463,8 @@ IMPL_LINK(GalleryBrowser1, PopupMenuHdl, const 
CommandEvent&, rCEvt, bool)
 
 IMPL_LINK_NOARG(GalleryBrowser1, SelectThemeHdl, weld::TreeView&, void)
 {
-if (maThemeSlectionHandler)
-maThemeSlectionHandler();
+if (maThemeSelectionHandler)
+maThemeSelectionHandler();
 }
 
 IMPL_LINK_NOARG(GalleryBrowser1, ClickNewThemeHdl, weld::Button&, void)
diff --git a/svx/source/gallery2/galbrws1.hxx b/svx/source/gallery2/galbrws1.hxx
index 91524f2022d3..835a0db4ec9a 100644
--- a/svx/source/gallery2/galbrws1.hxx
+++ b/svx/source/gallery2/galbrws1.hxx
@@ -53,7 +53,7 @@ private:
 OUString aImgDefault;
 OUString aImgReadOnly;
 
-::std::function maThemeSlectionHandler;
+::std::function maThemeSelectionHandler;
 
 voidImplInsertThemeEntry( const GalleryThemeEntry* 
pEntry );
 static void ImplFillExchangeData( const GalleryTheme* pThm, 
ExchangeData& rData );
@@ -77,7 +77,7 @@ public:
 GalleryBrowser1(
 weld::Builder& rBuilder,
 Gallery* pGallery,
-const ::std::function& 
rThemeSlectionHandler);
+const ::std::function& 
rThemeSelectionHandler);
 
 ~GalleryBrowser1();
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: xmloff/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 xmloff/source/forms/elementexport.cxx  |4 ++--
 xmloff/source/forms/elementimport.cxx  |2 +-
 xmloff/source/forms/formattributes.cxx |2 +-
 xmloff/source/forms/formattributes.hxx |2 +-
 4 files changed, 5 insertions(+), 5 deletions(-)

New commits:
commit 65aa9f9360daaf09cc2e3f14f19c859c883144c2
Author: Andrea Gelmini 
AuthorDate: Fri Aug 28 14:36:23 2020 +0200
Commit: Noel Grandin 
CommitDate: Mon Aug 31 08:31:14 2020 +0200

Fix typo in code

It passed "make check" on Linux

Change-Id: Iaa9bca078574b85182bdc8c002123178d074b650
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101622
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/xmloff/source/forms/elementexport.cxx 
b/xmloff/source/forms/elementexport.cxx
index 7398ecee2a3c..a60d70437d9e 100644
--- a/xmloff/source/forms/elementexport.cxx
+++ b/xmloff/source/forms/elementexport.cxx
@@ -2175,8 +2175,8 @@ namespace xmloff
 PROPERTY_MASTERFIELDS);
 // detail fields
 exportStringSequenceAttribute(
-OAttributeMetaData::getFormAttributeNamespace(faDetailFiels),
-OAttributeMetaData::getFormAttributeName(faDetailFiels),
+OAttributeMetaData::getFormAttributeNamespace(faDetailFields),
+OAttributeMetaData::getFormAttributeName(faDetailFields),
 PROPERTY_DETAILFIELDS);
 }
 }   // namespace xmloff
diff --git a/xmloff/source/forms/elementimport.cxx 
b/xmloff/source/forms/elementimport.cxx
index 3fe06973d8cf..1cd555fee82e 100644
--- a/xmloff/source/forms/elementimport.cxx
+++ b/xmloff/source/forms/elementimport.cxx
@@ -1948,7 +1948,7 @@ namespace xmloff
 {
 // handle the master/details field attributes (they're way too special 
to let the OPropertyImport handle them)
 static const char* s_sMasterFieldsAttributeName = 
OAttributeMetaData::getFormAttributeName(faMasterFields);
-static const char* s_sDetailFieldsAttributeName = 
OAttributeMetaData::getFormAttributeName(faDetailFiels);
+static const char* s_sDetailFieldsAttributeName = 
OAttributeMetaData::getFormAttributeName(faDetailFields);
 
 if ( _rLocalName.equalsAscii(s_sMasterFieldsAttributeName) )
 {
diff --git a/xmloff/source/forms/formattributes.cxx 
b/xmloff/source/forms/formattributes.cxx
index efc61abfa23a..e3da354d9996 100644
--- a/xmloff/source/forms/formattributes.cxx
+++ b/xmloff/source/forms/formattributes.cxx
@@ -94,7 +94,7 @@ namespace xmloff
 case faCommandType: return "command-type";
 case faEscapeProcessing:return "escape-processing";
 case faDatasource:  return "datasource";
-case faDetailFiels: return "detail-fields";
+case faDetailFields:return "detail-fields";
 case faFilter:  return "filter";
 case faIgnoreResult:return "ignore-result";
 case faMasterFields:return "master-fields";
diff --git a/xmloff/source/forms/formattributes.hxx 
b/xmloff/source/forms/formattributes.hxx
index 72dbc587f9fa..56c18a896ac9 100644
--- a/xmloff/source/forms/formattributes.hxx
+++ b/xmloff/source/forms/formattributes.hxx
@@ -153,7 +153,7 @@ namespace xmloff
 faCommandType,
 faEscapeProcessing,
 faDatasource,
-faDetailFiels,
+faDetailFields,
 faFilter,
 faIgnoreResult,
 faMasterFields,
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: Branch 'distro/collabora/cp-6.4' - 10 commits - cui/source readlicense_oo/license sw/qa sw/source writerfilter/source

2020-08-30 Thread Vasily Melenchuk (via logerrit)
 cui/source/inc/chardlg.hxx|   11 
 cui/source/tabpages/chardlg.cxx   |   77 
 readlicense_oo/license/CREDITS.fodt   | 4269 +++---
 sw/qa/extras/ooxmlexport/data/tdf131801.docx  |binary
 sw/qa/extras/ooxmlexport/data/tdf135973.odt   |binary
 sw/qa/extras/ooxmlexport/ooxmlexport15.cxx|   74 
 sw/qa/extras/uiwriter/data/tdf132160.odt  |binary
 sw/qa/extras/uiwriter/uiwriter.cxx|   18 
 sw/source/core/attr/swatrset.cxx  |   10 
 sw/source/core/doc/DocumentLayoutManager.cxx  |9 
 sw/source/core/doc/DocumentRedlineManager.cxx |   59 
 sw/source/core/docnode/ndsect.cxx |1 
 sw/source/core/text/txtfld.cxx|   30 
 sw/source/core/txtnode/ndtxt.cxx  |5 
 sw/source/core/unocore/unoobj.cxx |   11 
 sw/source/filter/ww8/wrtw8nds.cxx |3 
 sw/source/filter/ww8/wrtw8num.cxx |   30 
 sw/source/filter/ww8/wrtww8.hxx   |3 
 sw/source/filter/ww8/ww8atr.cxx   |  158 
 writerfilter/source/dmapper/DomainMapper_Impl.cxx |4 
 20 files changed, 2535 insertions(+), 2237 deletions(-)

New commits:
commit 9cb9bc37d1fcd7b61d218ad63893db92a19a0cb6
Author: Vasily Melenchuk 
AuthorDate: Tue Aug 18 17:59:26 2020 +0200
Commit: Andras Timar 
CommitDate: Mon Aug 31 07:18:48 2020 +0200

tdf#131801: sw: support of style references in ListAutoFormat

ListAutoFormat property did support char attributes, but not
style references ("CharStyleName"). It is important for correct
formatting of pilcrow symbol or list format in some DOCX scenarios.

Export to DOCX already works, but not to RTF/DOC.

Change-Id: I1bf23d1e45fcc213adcf9aa6f404be803919fbee
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/100893
Tested-by: Michael Stahl 
Reviewed-by: Michael Stahl 
(cherry picked from commit c77b9c349f0a48392d8cb7a49532844b2cafb5ba)
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101560
Tested-by: Jenkins

diff --git a/sw/qa/extras/ooxmlexport/data/tdf131801.docx 
b/sw/qa/extras/ooxmlexport/data/tdf131801.docx
new file mode 100644
index ..61872b5399f5
Binary files /dev/null and b/sw/qa/extras/ooxmlexport/data/tdf131801.docx differ
diff --git a/sw/qa/extras/ooxmlexport/ooxmlexport15.cxx 
b/sw/qa/extras/ooxmlexport/ooxmlexport15.cxx
index 2942b74dd194..a20a93c93637 100644
--- a/sw/qa/extras/ooxmlexport/ooxmlexport15.cxx
+++ b/sw/qa/extras/ooxmlexport/ooxmlexport15.cxx
@@ -9,6 +9,7 @@
 
 #include 
 
+#include 
 #include 
 
 char const DATA_DIRECTORY[] = "/sw/qa/extras/ooxmlexport/data/";
@@ -33,6 +34,58 @@ DECLARE_OOXMLEXPORT_TEST(testTdf14_followPgStyle, 
"tdf14_followPgStyle.o
 CPPUNIT_ASSERT_EQUAL(2, getPages());
 }
 
+DECLARE_OOXMLIMPORT_TEST(testTdf131801, "tdf131801.docx")
+{
+CPPUNIT_ASSERT_EQUAL(1, getPages());
+
+xmlDocPtr pDump = parseLayoutDump();
+// "1." is red
+CPPUNIT_ASSERT_EQUAL(OUString("1."), getXPath(pDump, 
"//page[1]/body/txt[1]/Special", "rText"));
+CPPUNIT_ASSERT_EQUAL(OUString("00ff"), getXPath(pDump, 
"//page[1]/body/txt[1]/Special/SwFont", "color"));
+// "2." is red
+CPPUNIT_ASSERT_EQUAL(OUString("2."), getXPath(pDump, 
"//page[1]/body/txt[2]/Special", "rText"));
+CPPUNIT_ASSERT_EQUAL(OUString("00ff"), getXPath(pDump, 
"//page[1]/body/txt[2]/Special/SwFont", "color"));
+// "3." is black
+CPPUNIT_ASSERT_EQUAL(OUString("3."), getXPath(pDump, 
"//page[1]/body/txt[3]/Special", "rText"));
+CPPUNIT_ASSERT_EQUAL(OUString(""), getXPath(pDump, 
"//page[1]/body/txt[3]/Special/SwFont", "color"));
+// "4." is black
+CPPUNIT_ASSERT_EQUAL(OUString("4."), getXPath(pDump, 
"//page[1]/body/txt[4]/Special", "rText"));
+CPPUNIT_ASSERT_EQUAL(OUString(""), getXPath(pDump, 
"//page[1]/body/txt[4]/Special/SwFont", "color"));
+// "5." is red
+CPPUNIT_ASSERT_EQUAL(OUString("5."), getXPath(pDump, 
"//page[1]/body/txt[5]/Special", "rText"));
+CPPUNIT_ASSERT_EQUAL(OUString("00ff"), getXPath(pDump, 
"//page[1]/body/txt[5]/Special/SwFont", "color"));
+// "6." is red
+CPPUNIT_ASSERT_EQUAL(OUString("6."), getXPath(pDump, 
"//page[1]/body/txt[6]/Special", "rText"));
+CPPUNIT_ASSERT_EQUAL(OUString("00ff"), getXPath(pDump, 
"//page[1]/body/txt[6]/Special/SwFont", "color"));
+// "7." is black
+CPPUNIT_ASSERT_EQUAL(OUString("7."), getXPath(pDump, 
"//page[1]/body/txt[7]/Special", "rText"));
+CPPUNIT_ASSERT_EQUAL(OUString(""), getXPath(pDump, 
"//page[1]/body/txt[7]/Special/SwFont", "color"));
+// "8." is black
+CPPUNIT_ASSERT_EQUAL(OUString("8."), getXPath(pDump, 
"//page[1]/body/txt[8]/Special[1]", "rText"));
+CPPUNIT_ASSERT_EQUAL(OUString(""), getXPath(pDump, 
"//page[1]/body/txt[8]/Special[1]/SwFont", "color"));
+
+xmlDocPtr pXmlDocume

[Libreoffice-commits] core.git: helpcontent2

2020-08-30 Thread Olivier Hallot (via logerrit)
 helpcontent2 |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 1e0cfd5662d95cea84e80e4fe10d52c3b1101ae6
Author: Olivier Hallot 
AuthorDate: Sun Aug 30 22:01:48 2020 +0200
Commit: Gerrit Code Review 
CommitDate: Sun Aug 30 22:01:48 2020 +0200

Update git submodules

* Update helpcontent2 from branch 'master'
  to aeb5cc458fce90b7f5c02128e95bad89f92b3efd
  - Typo.

Change-Id: I6706a7811e93de08281900012a302e6431caa899
Reviewed-on: https://gerrit.libreoffice.org/c/help/+/101668
Tested-by: Jenkins
Reviewed-by: Olivier Hallot 

diff --git a/helpcontent2 b/helpcontent2
index da7d4570411e..aeb5cc458fce 16
--- a/helpcontent2
+++ b/helpcontent2
@@ -1 +1 @@
-Subproject commit da7d4570411ec5324a68e4e3a671fde9f66355c8
+Subproject commit aeb5cc458fce90b7f5c02128e95bad89f92b3efd
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] help.git: source/text

2020-08-30 Thread Olivier Hallot (via logerrit)
 source/text/shared/05/err_html.xhp |6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit aeb5cc458fce90b7f5c02128e95bad89f92b3efd
Author: Olivier Hallot 
AuthorDate: Sun Aug 30 15:19:23 2020 +0200
Commit: Olivier Hallot 
CommitDate: Sun Aug 30 22:01:48 2020 +0200

Typo.

Change-Id: I6706a7811e93de08281900012a302e6431caa899
Reviewed-on: https://gerrit.libreoffice.org/c/help/+/101668
Tested-by: Jenkins
Reviewed-by: Olivier Hallot 

diff --git a/source/text/shared/05/err_html.xhp 
b/source/text/shared/05/err_html.xhp
index 446622431..1fd8a27b5 100644
--- a/source/text/shared/05/err_html.xhp
+++ b/source/text/shared/05/err_html.xhp
@@ -32,15 +32,15 @@
   That is an 
error. Possible causes are:
 
 
-The page does 
not exists and must be created.
+The page does 
not exist and must be created.
 
 
-The page 
exists, but the Help ID is wrong or missing.
+The page exist, 
but the Help ID is wrong or missing.
 
 
 Use the Module, 
Contents, Index and Search selectors to find the right page.
 
 The following data 
could be helpful in locating the error:
-  Help ID: 

+Help ID: 

 
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: framework/source

2020-08-30 Thread Maxim Monastirsky (via logerrit)
 framework/source/fwe/classes/addonsoptions.cxx |   26 +
 1 file changed, 14 insertions(+), 12 deletions(-)

New commits:
commit 15d655f0133d986a85f4ba9630587566d90a0c50
Author: Maxim Monastirsky 
AuthorDate: Sun Aug 30 19:04:03 2020 +0300
Commit: Maxim Monastirsky 
CommitDate: Sun Aug 30 21:33:26 2020 +0200

Related: tdf#107548 Make sure embedded images have higher priority

As documented in the schema, the dev guide and a comment in
AddonsOptions_Impl::ReadImageData. Noticed the problem while testing
the ProtocolHandlerAddon sdk example which has the ImageSmall props
defined yet didn't show the icons. Turned out this was a result of
the previous commit that fixed ImageSmallURL, which started now to
override ImageSmall.

Change-Id: I0a9eb6b13b73a60efc801905601894c862d68cba
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101666
Tested-by: Jenkins
Reviewed-by: Maxim Monastirsky 

diff --git a/framework/source/fwe/classes/addonsoptions.cxx 
b/framework/source/fwe/classes/addonsoptions.cxx
index 4201a6a5f4f7..00766c66e208 100644
--- a/framework/source/fwe/classes/addonsoptions.cxx
+++ b/framework/source/fwe/classes/addonsoptions.cxx
@@ -256,7 +256,8 @@ class AddonsOptions_Impl : public ConfigItem
 // accessed in this order
 OneImageEntry aSizeEntry[2];
 ImageEntry() {}
-void addImage(ImageSize eSize, const BitmapEx &rImage, const 
OUString &rURL);
+void addImage(ImageSize eSize, const BitmapEx &rImage);
+void addImage(ImageSize eSize, const OUString &rURL);
 };
 
 typedef std::unordered_map< OUString, ImageEntry > ImageManager;
@@ -349,11 +350,13 @@ class AddonsOptions_Impl : public ConfigItem
 MergeStatusbarInstructionContainer
m_aCachedStatusbarMergingInstructions;
 };
 
-void AddonsOptions_Impl::ImageEntry::addImage(ImageSize eSize,
-  const BitmapEx& rImage,
-  const OUString &rURL)
+void AddonsOptions_Impl::ImageEntry::addImage(ImageSize eSize, const BitmapEx& 
rImage)
 {
 aSizeEntry[static_cast(eSize)].aImage = rImage;
+}
+
+void AddonsOptions_Impl::ImageEntry::addImage(ImageSize eSize, const OUString 
&rURL)
+{
 aSizeEntry[static_cast(eSize)].aURL = rURL;
 }
 
@@ -1608,8 +1611,7 @@ void AddonsOptions_Impl::ReadAndAssociateImages( const 
OUString& aURL, const OUS
 aFileURL.appendAscii( aExtArray[i] );
 aFileURL.append( ".bmp" );
 
-aImageEntry.addImage( !i ? IMGSIZE_SMALL : IMGSIZE_BIG,
-  BitmapEx(), aFileURL.makeStringAndClear() );
+aImageEntry.addImage( !i ? IMGSIZE_SMALL : IMGSIZE_BIG, 
aFileURL.makeStringAndClear() );
 }
 
 m_aImageManager.emplace( aURL, aImageEntry );
@@ -1639,7 +1641,7 @@ std::unique_ptr 
AddonsOptions_Impl::ReadImageDat
 {
 if ( !pEntry )
 pEntry.reset(new ImageEntry);
-pEntry->addImage(i == OFFSET_IMAGES_SMALL ? IMGSIZE_SMALL : 
IMGSIZE_BIG, aImage, "");
+pEntry->addImage(i == OFFSET_IMAGES_SMALL ? IMGSIZE_SMALL : 
IMGSIZE_BIG, aImage);
 }
 }
 else if ( i == OFFSET_IMAGES_SMALL_URL || i == OFFSET_IMAGES_BIG_URL )
@@ -1649,11 +1651,11 @@ std::unique_ptr 
AddonsOptions_Impl::ReadImageDat
 
 // Retrieve image data from an external bitmap file. Make sure 
that embedded image data
 // has a higher priority.
-aPropertyData[i] >>= aImageURL;
-
-SubstituteVariables( aImageURL );
-
-pEntry->addImage(i == OFFSET_IMAGES_SMALL_URL ? IMGSIZE_SMALL : 
IMGSIZE_BIG, BitmapEx(), aImageURL);
+if (aPropertyData[i] >>= aImageURL)
+{
+SubstituteVariables(aImageURL);
+pEntry->addImage(i == OFFSET_IMAGES_SMALL_URL ? IMGSIZE_SMALL 
: IMGSIZE_BIG, aImageURL);
+}
 }
 }
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: codemaker/source connectivity/source i18npool/source idlc/source include/rtl oox/source opencl/source sal/qa sdext/source sfx2/source stoc/source svtools/source sw/sour

2020-08-30 Thread Stephan Bergmann (via logerrit)
 codemaker/source/javamaker/javatype.cxx   |2 
 connectivity/source/drivers/postgresql/pq_preparedstatement.cxx   |2 
 i18npool/source/breakiterator/breakiterator_unicode.cxx   |2 
 i18npool/source/breakiterator/xdictionary.cxx |4 
 i18npool/source/localedata/localedata.cxx |   10 -
 idlc/source/options.cxx   |5 
 include/rtl/strbuf.hxx|   19 +-
 include/rtl/string.hxx|   25 ++
 include/rtl/stringconcat.hxx  |   87 
--
 include/rtl/ustrbuf.hxx   |   19 +-
 include/rtl/ustring.hxx   |   25 ++
 oox/source/core/relationshandler.cxx  |6 
 opencl/source/openclwrapper.cxx   |2 
 sal/qa/rtl/strings/test_ostring_concat.cxx|   17 +
 sal/qa/rtl/strings/test_oustring_concat.cxx   |   18 +-
 sdext/source/pdfimport/sax/emitcontext.cxx|2 
 sfx2/source/appl/appuno.cxx   |4 
 stoc/source/uriproc/UriSchemeParser_vndDOTsunDOTstarDOTscript.cxx |2 
 svtools/source/svhtml/htmlout.cxx |2 
 sw/source/filter/html/htmlftn.cxx |2 
 tools/source/fsys/urlobj.cxx  |8 
 ucb/source/ucp/webdav/SerfPutReqProcImpl.cxx  |2 
 vcl/source/gdi/pdfwriter_impl.cxx |2 
 vcl/source/opengl/OpenGLHelper.cxx|2 
 24 files changed, 172 insertions(+), 97 deletions(-)

New commits:
commit 2e21240f23ac2191a3535d697a7308b29303c67c
Author: Stephan Bergmann 
AuthorDate: Fri Aug 28 17:14:50 2020 +0200
Commit: Stephan Bergmann 
CommitDate: Sun Aug 30 20:42:56 2020 +0200

Goodbye O[U]StringView, welcome O[U]String::Concat

O[U]StringView had an odd mixture of uses.  For one, it was used like
std::[u16]string_view, for which directly using the latter std types is 
clearly
the better alternative.  For another, it was used in concatenation 
sequences,
when neither of the two leading terms were of our rtl string-related types.

For that second use case introduce O[U]String::Concat (as 
std::[u16]string_view
can obviously not be used, those not being one of our rtl string-related 
types).
Also, O[U]StringLiteral is occasionally used for this, but the planned 
changes
outlined in the 33ecd0d5c4fff9511a8436513936a3f7044a775a "Change 
OUStringLiteral
from char[] to char16_t[]" commit message will make that no longer work, so
O[U]String::Concat will be the preferred solution in such use cases going
forward, too.

O[U]StringView was also occasionally used to include O[U]StringBuffer 
values in
concatenation sequences, for which a more obvious alternative is to make
O[U]StringBuffer participate directly in the ToStringHelper/O[U]StringConcat
machinery.

Change-Id: I1f0e8d836796c9ae01c45f32c518be5f52976622
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101586
Tested-by: Jenkins
Reviewed-by: Stephan Bergmann 

diff --git a/codemaker/source/javamaker/javatype.cxx 
b/codemaker/source/javamaker/javatype.cxx
index f800d7365852..3fdf79abe300 100644
--- a/codemaker/source/javamaker/javatype.cxx
+++ b/codemaker/source/javamaker/javatype.cxx
@@ -379,7 +379,7 @@ void MethodDescriptor::addTypeParameter(OUString const & 
name) {
 }
 
 OString MethodDescriptor::getDescriptor() const {
-return rtl::OStringView(m_descriptorStart) + m_descriptorEnd;
+return m_descriptorStart + m_descriptorEnd;
 }
 
 
diff --git a/connectivity/source/drivers/postgresql/pq_preparedstatement.cxx 
b/connectivity/source/drivers/postgresql/pq_preparedstatement.cxx
index 30d386a6cd3c..5c827b3bc0b7 100644
--- a/connectivity/source/drivers/postgresql/pq_preparedstatement.cxx
+++ b/connectivity/source/drivers/postgresql/pq_preparedstatement.cxx
@@ -489,7 +489,7 @@ void PreparedStatement::setBytes(
 *this, OUString(), 1, Any() );
 }
 m_vars[parameterIndex-1]
-= "'" + rtl::OStringView(reinterpret_cast(escapedString.get()), len -1) + "'";
+= OString::Concat("'") + std::string_view(reinterpret_cast(escapedString.get()), len -1) + "'";
 }
 
 
diff --git a/i18npool/source/breakiterator/breakiterator_unicode.cxx 
b/i18npool/source/breakiterator/breakiterator_unicode.cxx
index 7c79b99ec028..bb8d7d9862aa 100644
--- a/i18npool/source/breakiterator/breakiterator_unicode.cxx
+++ b/i18npool/source/breakiterator/breakiterator_unicode.cxx
@@ -199,7 +199,7 @@ void BreakIterator_Unicode::loadICUBreakIterator(const 
css::lang::Locale& rLocal
   

[Libreoffice-commits] core.git: cui/source cui/uiconfig

2020-08-30 Thread Yusuf Keten (via logerrit)
 cui/source/dialogs/AdditionsDialog.cxx |5 -
 cui/uiconfig/ui/additionsfragment.ui   |   14 +++---
 2 files changed, 11 insertions(+), 8 deletions(-)

New commits:
commit 6379f799704935a571a4b3af44cabd0671c48dbe
Author: Yusuf Keten 
AuthorDate: Fri Aug 28 13:57:57 2020 +0300
Commit: Muhammet Kara 
CommitDate: Sun Aug 30 19:44:40 2020 +0200

tdf#135273: Tight integration dialog shows unclear properties

When there is no info about the author of the extension, the label was NULL.
If it is null, it will be empty after this patch.

The initial label of the labelAuthor is cleared. Also, unnecessary 
translatable expressions in the additionsfragment.ui were deleted.

Change-Id: Iab9517f1b3ff5d8c6b3947d7b29c897c18e94664
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101537
Tested-by: Muhammet Kara 
Reviewed-by: Muhammet Kara 

diff --git a/cui/source/dialogs/AdditionsDialog.cxx 
b/cui/source/dialogs/AdditionsDialog.cxx
index 7d26416c910c..3586704a1e9b 100644
--- a/cui/source/dialogs/AdditionsDialog.cxx
+++ b/cui/source/dialogs/AdditionsDialog.cxx
@@ -685,7 +685,10 @@ AdditionsItem::AdditionsItem(weld::Widget* pParent, 
AdditionsDialog* pParentDial
 
 m_xLinkButtonName->set_uri(additionInfo.sExtensionURL);
 m_xLabelDescription->set_label(additionInfo.sIntroduction);
-m_xLabelAuthor->set_label(additionInfo.sAuthorName);
+
+if (!additionInfo.sAuthorName.equalsIgnoreAsciiCase("null"))
+m_xLabelAuthor->set_label(additionInfo.sAuthorName);
+
 m_xButtonInstall->set_label(CuiResId(RID_SVXSTR_ADDITIONS_INSTALLBUTTON));
 OUString sLicenseString = CuiResId(RID_SVXSTR_ADDITIONS_LICENCE) + 
additionInfo.sLicense;
 m_xLabelLicense->set_label(sLicenseString);
diff --git a/cui/uiconfig/ui/additionsfragment.ui 
b/cui/uiconfig/ui/additionsfragment.ui
index 93c8e50ad126..cc1701dfce82 100644
--- a/cui/uiconfig/ui/additionsfragment.ui
+++ b/cui/uiconfig/ui/additionsfragment.ui
@@ -77,7 +77,7 @@
 top
 
   
-button
+button
 True
 True
 True
@@ -97,7 +97,7 @@
 True
 False
 start
-label
+
   
   
 False
@@ -125,7 +125,7 @@
 False
 start
 start
-label
+label
 True
 word-char
 1
@@ -146,7 +146,7 @@
 False
 start
 3
-label
+label
   
   
 False
@@ -160,7 +160,7 @@
 False
 start
 3
-label
+label
   
   
 False
@@ -187,7 +187,7 @@
 
 
   
-button
+button
 True
 True
 True
@@ -338,7 +338,7 @@
 True
 False
 start
-label
+label
 
   
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


unit tests taking focus on the desktop

2020-08-30 Thread Terrence Enger
All,

I notice that unit tests (UIT, it seems) are launching 
LibreOffice to take focus on the desktop.  I am running 
debian-buster and xfce desktop.

Is there a way to either
(*) send that user interface away somewhere, so that I can
do other things in the desktop?
(*) make the tests continue after desktop locks, so  that
I can go away to do other things?

Thanks for your attention,
Terry.


___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: forms/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 forms/source/component/FormComponent.cxx |   10 +-
 forms/source/inc/FormComponent.hxx   |2 +-
 2 files changed, 6 insertions(+), 6 deletions(-)

New commits:
commit 0d2dbcbebf0004e690feb91c38dd478a32dc6255
Author: Andrea Gelmini 
AuthorDate: Sat Aug 29 19:28:22 2020 +0200
Commit: Julien Nabet 
CommitDate: Sun Aug 30 15:16:07 2020 +0200

Fix typo in code

Change-Id: Ia2820c68109c84b52173beafe2cf301104d80831
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101652
Tested-by: Jenkins
Reviewed-by: Julien Nabet 

diff --git a/forms/source/component/FormComponent.cxx 
b/forms/source/component/FormComponent.cxx
index 34b5f51c538d..c8bad80d0ae6 100644
--- a/forms/source/component/FormComponent.cxx
+++ b/forms/source/component/FormComponent.cxx
@@ -1145,7 +1145,7 @@ OBoundControlModel::OBoundControlModel(
 ,m_bSupportsExternalBinding( _bSupportExternalBinding )
 ,m_bSupportsValidation( _bSupportsValidation )
 ,m_bForwardValueChanges(true)
-,m_bTransferingValue( false )
+,m_bTransferringValue( false )
 ,m_bIsCurrentValueValid( true )
 ,m_bBindingControlsRO( false )
 ,m_bBindingControlsEnable( false )
@@ -1178,7 +1178,7 @@ OBoundControlModel::OBoundControlModel(
 ,m_bSupportsExternalBinding( _pOriginal->m_bSupportsExternalBinding )
 ,m_bSupportsValidation( _pOriginal->m_bSupportsValidation )
 ,m_bForwardValueChanges( true )
-,m_bTransferingValue( false )
+,m_bTransferringValue( false )
 ,m_bIsCurrentValueValid( _pOriginal->m_bIsCurrentValueValid )
 ,m_bBindingControlsRO( false )
 ,m_bBindingControlsEnable( false )
@@ -2509,7 +2509,7 @@ void SAL_CALL OBoundControlModel::modified( const 
EventObject& _rEvent )
 {
 ControlModelLock aLock( *this );
 OSL_PRECOND( hasExternalValueBinding(), "OBoundControlModel::modified: 
Where did this come from?" );
-if ( !m_bTransferingValue && ( m_xExternalBinding == _rEvent.Source ) && 
m_xExternalBinding.is() )
+if ( !m_bTransferringValue && ( m_xExternalBinding == _rEvent.Source ) && 
m_xExternalBinding.is() )
 {
 transferExternalValueToControl( aLock );
 }
@@ -2557,7 +2557,7 @@ void OBoundControlModel::transferControlValueToExternal( 
ControlModelLock& _rIns
 return;
 
 Any aExternalValue( translateControlValueToExternalValue() );
-m_bTransferingValue = true;
+m_bTransferringValue = true;
 _rInstanceLock.release();
  // UNSAFE >
 try
@@ -2572,7 +2572,7 @@ void OBoundControlModel::transferControlValueToExternal( 
ControlModelLock& _rIns
 
 // < UNSAFE
 _rInstanceLock.acquire();
-m_bTransferingValue = false;
+m_bTransferringValue = false;
 }
 
 Sequence< Type > OBoundControlModel::getSupportedBindingTypes()
diff --git a/forms/source/inc/FormComponent.hxx 
b/forms/source/inc/FormComponent.hxx
index e13ef797f9fa..4a2fc4bf95ca 100644
--- a/forms/source/inc/FormComponent.hxx
+++ b/forms/source/inc/FormComponent.hxx
@@ -597,7 +597,7 @@ private:
 const bool  m_bSupportsExternalBinding  : 1;// do we 
support XBindableValue?
 const bool  m_bSupportsValidation   : 1;// do we 
support XValidatable?
 boolm_bForwardValueChanges  : 1;// do we 
currently handle changes in the bound database field?
-boolm_bTransferingValue : 1;// true if 
we're currently transferring our value to an external binding
+boolm_bTransferringValue: 1;// true if 
we're currently transferring our value to an external binding
 boolm_bIsCurrentValueValid  : 1;// flag 
specifying whether our current value is valid, relative to our external 
validator
 boolm_bBindingControlsRO: 1;// is our 
ReadOnly property currently controlled by our external binding?
 boolm_bBindingControlsEnable: 1;// is our 
Enabled property currently controlled by our external binding?
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: vcl/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 vcl/source/gdi/pdfwriter_impl.cxx |   12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)

New commits:
commit ac712c5c7b85893ee94f8f87e53d02fc3bfc9f9d
Author: Andrea Gelmini 
AuthorDate: Sat Aug 29 19:29:11 2020 +0200
Commit: Julien Nabet 
CommitDate: Sun Aug 30 15:14:53 2020 +0200

Fix typo in code

Change-Id: I02bc7257296939de1a5cbb708c6a9634a8d63ec5
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101653
Tested-by: Jenkins
Reviewed-by: Julien Nabet 

diff --git a/vcl/source/gdi/pdfwriter_impl.cxx 
b/vcl/source/gdi/pdfwriter_impl.cxx
index 0be50512d569..c879c9143858 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -4106,13 +4106,13 @@ bool PDFWriterImpl::emitAppearances( PDFWidget& 
rWidget, OStringBuffer& rAnnotDi
 
 for (auto const& stream_item : dict_item.second)
 {
-SvMemoryStream* pApppearanceStream = stream_item.second;
+SvMemoryStream* pAppearanceStream = stream_item.second;
 dict_item.second[ stream_item.first ] = nullptr;
 
-bool bDeflate = compressStream( pApppearanceStream );
+bool bDeflate = compressStream( pAppearanceStream );
 
-sal_Int64 nStreamLen = pApppearanceStream->TellEnd();
-pApppearanceStream->Seek( STREAM_SEEK_TO_BEGIN );
+sal_Int64 nStreamLen = pAppearanceStream->TellEnd();
+pAppearanceStream->Seek( STREAM_SEEK_TO_BEGIN );
 sal_Int32 nObject = createObject();
 CHECK_RETURN( updateObject( nObject ) );
 if (g_bDebugDisableCompression)
@@ -4141,7 +4141,7 @@ bool PDFWriterImpl::emitAppearances( PDFWidget& rWidget, 
OStringBuffer& rAnnotDi
 aLine.append( ">>\nstream\n" );
 CHECK_RETURN( writeBuffer( aLine.getStr(), aLine.getLength() ) 
);
 checkAndEnableStreamEncryption( nObject );
-CHECK_RETURN( writeBuffer( pApppearanceStream->GetData(), 
nStreamLen ) );
+CHECK_RETURN( writeBuffer( pAppearanceStream->GetData(), 
nStreamLen ) );
 disableStreamEncryption();
 CHECK_RETURN( writeBuffer( "\nendstream\nendobj\n\n", 19 ) );
 
@@ -4154,7 +4154,7 @@ bool PDFWriterImpl::emitAppearances( PDFWidget& rWidget, 
OStringBuffer& rAnnotDi
 rAnnotDict.append( nObject );
 rAnnotDict.append( " 0 R" );
 
-delete pApppearanceStream;
+delete pAppearanceStream;
 }
 
 rAnnotDict.append( bUseSubDict ? ">>\n" : "\n" );
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: qadevOOo/tests

2020-08-30 Thread Andrea Gelmini (via logerrit)
 qadevOOo/tests/java/ifc/container/_XHierarchicalName.java |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit bf6d42803a8977ba881da3b44e3e871cb9b84a5f
Author: Andrea Gelmini 
AuthorDate: Fri Aug 28 12:15:06 2020 +0200
Commit: Julien Nabet 
CommitDate: Sun Aug 30 13:55:44 2020 +0200

Fix typo in code

It passed "make check" on Linux

Change-Id: Id837205b0e6a7efa091a5b9ead75d767ceddcefa
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101598
Tested-by: Jenkins
Reviewed-by: Julien Nabet 

diff --git a/qadevOOo/tests/java/ifc/container/_XHierarchicalName.java 
b/qadevOOo/tests/java/ifc/container/_XHierarchicalName.java
index 83897bc43fb4..f828c1f61830 100644
--- a/qadevOOo/tests/java/ifc/container/_XHierarchicalName.java
+++ b/qadevOOo/tests/java/ifc/container/_XHierarchicalName.java
@@ -28,7 +28,7 @@ public class _XHierarchicalName extends MultiMethodTest {
 public XHierarchicalName oObj;
 
 public void _composeHierarchicalName() {
-String expName = (String) tEnv.getObjRelation("HierachicalName");
+String expName = (String) tEnv.getObjRelation("HierarchicalName");
 String element = (String) tEnv.getObjRelation("ElementName");
 boolean res = false;
 
@@ -51,7 +51,7 @@ public class _XHierarchicalName extends MultiMethodTest {
 
 public void _getHierarchicalName() {
 String hName = oObj.getHierarchicalName();
-String expName = (String) tEnv.getObjRelation("HierachicalName");
+String expName = (String) tEnv.getObjRelation("HierarchicalName");
 boolean res = true;
 System.out.println("### "+hName);
 if (expName != null) {
@@ -63,9 +63,9 @@ System.out.println("### "+hName);
 }
 } else {
 throw new StatusException(Status.failed(
-  "ObjectRelation 
'HierachicalName' missing"));
+  "ObjectRelation 
'HierarchicalName' missing"));
 }
 
 tRes.tested("getHierarchicalName()", res);
 }
-}
\ No newline at end of file
+}
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: forms/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 forms/source/component/ImageControl.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 2d9d9010ae817c3b9535c52f8a6529c88a0b4bfa
Author: Andrea Gelmini 
AuthorDate: Sat Aug 29 19:53:09 2020 +0200
Commit: Noel Grandin 
CommitDate: Sun Aug 30 13:52:47 2020 +0200

Fix typos

Change-Id: I1f8e27182352ebba878b120875eefc1aa5c7009f
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101654
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/forms/source/component/ImageControl.cxx 
b/forms/source/component/ImageControl.cxx
index 97928cff6fa9..b75080bae4a2 100644
--- a/forms/source/component/ImageControl.cxx
+++ b/forms/source/component/ImageControl.cxx
@@ -326,7 +326,7 @@ void OImageControlModel::describeAggregateProperties( 
Sequence< Property >& /* [
 OBoundControlModel::describeAggregateProperties( o_rAggregateProperties );
 // remove ImageURL and Graphic properties, we "override" them.
 // This is because our aggregate synchronizes those
-// two, but we have an own sychronization mechanism.
+// two, but we have an own synchronization mechanism.
 RemoveProperty( o_rAggregateProperties, PROPERTY_IMAGE_URL );
 RemoveProperty( o_rAggregateProperties, PROPERTY_GRAPHIC );
 }
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: qadevOOo/tests sw/qa

2020-08-30 Thread Andrea Gelmini (via logerrit)
 qadevOOo/tests/java/ifc/awt/_XScrollBar.java |2 +-
 qadevOOo/tests/java/ifc/awt/_XSpinValue.java |2 +-
 sw/qa/uitest/writer_tests2/formatBulletsNumbering.py |   14 +++---
 3 files changed, 9 insertions(+), 9 deletions(-)

New commits:
commit e20c899ec83fdf88ab4d39ada1e830f05f798341
Author: Andrea Gelmini 
AuthorDate: Sat Aug 29 19:17:58 2020 +0200
Commit: Noel Grandin 
CommitDate: Sun Aug 30 13:52:29 2020 +0200

Fix typos

Change-Id: I041e65166eab9fc497742635fe59e11f63d55c6d
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101645
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/qadevOOo/tests/java/ifc/awt/_XScrollBar.java 
b/qadevOOo/tests/java/ifc/awt/_XScrollBar.java
index 5dfae24fad4b..a298ed082904 100644
--- a/qadevOOo/tests/java/ifc/awt/_XScrollBar.java
+++ b/qadevOOo/tests/java/ifc/awt/_XScrollBar.java
@@ -51,7 +51,7 @@ public class _XScrollBar extends MultiMethodTest {
 }
 
 public void _removeAdjustmentListener() {
-//this method is checked in addAjustmentListener
+//this method is checked in addAdjustmentListener
 //so that method is required here and if it works
 //this method is given OK too
 requiredMethod("addAdjustmentListener()");
diff --git a/qadevOOo/tests/java/ifc/awt/_XSpinValue.java 
b/qadevOOo/tests/java/ifc/awt/_XSpinValue.java
index bc19d4fdaba7..a8a65e2db305 100644
--- a/qadevOOo/tests/java/ifc/awt/_XSpinValue.java
+++ b/qadevOOo/tests/java/ifc/awt/_XSpinValue.java
@@ -50,7 +50,7 @@ public class _XSpinValue extends MultiMethodTest {
 }
 
 public void _removeAdjustmentListener() {
-//this method is checked in addAjustmentListener
+//this method is checked in addAdjustmentListener
 //so that method is required here and if it works
 //this method is given OK too
 requiredMethod("addAdjustmentListener()");
diff --git a/sw/qa/uitest/writer_tests2/formatBulletsNumbering.py 
b/sw/qa/uitest/writer_tests2/formatBulletsNumbering.py
index f10f543af047..a7e3421e267e 100644
--- a/sw/qa/uitest/writer_tests2/formatBulletsNumbering.py
+++ b/sw/qa/uitest/writer_tests2/formatBulletsNumbering.py
@@ -306,12 +306,12 @@ class formatBulletsNumbering(UITestCase):
 xBulletPage = xDialog.getChild("PickBulletPage")
 xselector = xBulletPage.getChild("valueset")
 self.assertEqual(get_state_as_dict(xselector)["ItemsCount"], "8")
-# Select elemet num 3
+# Select element num 3
 xselector.executeAction("CHOOSE", mkPropertyValues({"POS": "3"}))
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemPos"], "2")
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemId"], "3")
 self.assertEqual(get_state_as_dict(xselector)["ItemText"], "Solid 
diamond bullets")
-# Select elemet num 7
+# Select element num 7
 xselector.executeAction("CHOOSE", mkPropertyValues({"POS": "7"}))
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemPos"], "6")
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemId"], "7")
@@ -329,12 +329,12 @@ class formatBulletsNumbering(UITestCase):
 xNumberingPage = xDialog.getChild("PickNumberingPage")
 xselector = xNumberingPage.getChild("valueset")
 self.assertEqual(get_state_as_dict(xselector)["ItemsCount"], "8")
-# Select elemet num 5
+# Select element num 5
 xselector.executeAction("CHOOSE", mkPropertyValues({"POS": "5"}))
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemPos"], "4")
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemId"], "5")
 self.assertEqual(get_state_as_dict(xselector)["ItemText"], "Uppercase 
letter A) B) C)")
-# Select elemet num 8
+# Select element num 8
 xselector.executeAction("CHOOSE", mkPropertyValues({"POS": "8"}))
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemPos"], "7")
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemId"], "8")
@@ -346,7 +346,7 @@ class formatBulletsNumbering(UITestCase):
 xOutlinePage = xDialog.getChild("PickOutlinePage")
 xselector = xOutlinePage.getChild("valueset")
 self.assertEqual(get_state_as_dict(xselector)["ItemsCount"], "8")
-# Select elemet num 1
+# Select element num 1
 xselector.executeAction("CHOOSE", mkPropertyValues({"POS": "1"}))
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemPos"], "0")
 self.assertEqual(get_state_as_dict(xselector)["SelectedItemId"], "1")
@@ -358,11 +358,11 @@ class formatBulletsNumbering(UITestCase):
 xGraphicPage = xDialog.getChild("PickGraphicPage")
 xselector = xGraphicPage.getChild("valueset")
 self.assertEqual(get_state_as_dict(xselector)["ItemsCount"], "92")
-# Select elemet num 22
+# Select element num 22
 xselector.executeA

[Libreoffice-commits] core.git: schema/mathml2

2020-08-30 Thread Andrea Gelmini (via logerrit)
 schema/mathml2/content/semantics.xsd |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 8750cbc7f609c5de77796b179425469dbdcfdcb5
Author: Andrea Gelmini 
AuthorDate: Sat Aug 22 23:04:45 2020 +0200
Commit: Noel Grandin 
CommitDate: Sun Aug 30 13:51:58 2020 +0200

Fix typo in code

Change-Id: I22e37a583f673d0bd02c74a6b05c0a0e25ed3722
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101215
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/schema/mathml2/content/semantics.xsd 
b/schema/mathml2/content/semantics.xsd
index d337ee76f11c..0d6ad693b3c3 100644
--- a/schema/mathml2/content/semantics.xsd
+++ b/schema/mathml2/content/semantics.xsd
@@ -9,7 +9,7 @@
 
 
   
-  This is an XML Schema module for the "sematics" element of content MathML.
+  This is an XML Schema module for the "semantics" element of content MathML.
   Author: Stéphane Dalmas, INRIA.
   
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: svx/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 svx/source/fmcomp/gridcell.cxx |   10 +-
 1 file changed, 5 insertions(+), 5 deletions(-)

New commits:
commit c57d9a50369b39775be931753e83aacfee56504b
Author: Andrea Gelmini 
AuthorDate: Sat Aug 29 19:26:50 2020 +0200
Commit: Noel Grandin 
CommitDate: Sun Aug 30 13:51:19 2020 +0200

Fix typo in code

Change-Id: Ib7f77b2c84c375158d88114e827754f47ee246bd
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101651
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/svx/source/fmcomp/gridcell.cxx b/svx/source/fmcomp/gridcell.cxx
index 405c3522dc6b..e822a89dc961 100644
--- a/svx/source/fmcomp/gridcell.cxx
+++ b/svx/source/fmcomp/gridcell.cxx
@@ -1314,9 +1314,9 @@ void DbFormattedField::Init( BrowserDataWin& rParent, 
const Reference< XRowSet >
 SvNumberFormatter* pFormatterUsed = nullptr;
 if (m_xSupplier.is())
 {
-SvNumberFormatsSupplierObj* pImplmentation = 
comphelper::getUnoTunnelImplementation(m_xSupplier);
-if (pImplmentation)
-pFormatterUsed = pImplmentation->GetNumberFormatter();
+SvNumberFormatsSupplierObj* pImplementation = 
comphelper::getUnoTunnelImplementation(m_xSupplier);
+if (pImplementation)
+pFormatterUsed = pImplementation->GetNumberFormatter();
 else
 // Everything is invalid: the supplier is of the wrong type, then 
we can not
 // rely on a standard formatter to know the (possibly 
non-standard) key.
@@ -1902,8 +1902,8 @@ void DbNumericField::implAdjustGenericFieldSetting( const 
Reference< XPropertySe
 SvNumberFormatter* pFormatterUsed = nullptr;
 if ( xSupplier.is() )
 {
-SvNumberFormatsSupplierObj* pImplmentation = 
comphelper::getUnoTunnelImplementation( xSupplier );
-pFormatterUsed = pImplmentation ? pImplmentation->GetNumberFormatter() 
: nullptr;
+SvNumberFormatsSupplierObj* pImplementation = 
comphelper::getUnoTunnelImplementation( xSupplier );
+pFormatterUsed = pImplementation ? 
pImplementation->GetNumberFormatter() : nullptr;
 }
 if ( nullptr == pFormatterUsed )
 {   // the cursor didn't lead to success -> standard
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: dbaccess/source include/xmloff reportdesign/source sc/source sw/source xmloff/inc xmloff/source

2020-08-30 Thread Noel Grandin (via logerrit)
 dbaccess/source/filter/xml/xmlStyleImport.cxx   |7 
 dbaccess/source/filter/xml/xmlStyleImport.hxx   |3 
 include/xmloff/XMLDrawingPageStyleContext.hxx   |8 
 include/xmloff/XMLGraphicsDefaultStyle.hxx  |3 
 include/xmloff/XMLShapeStyleContext.hxx |2 
 include/xmloff/XMLTextShapeStyleContext.hxx |3 
 include/xmloff/prstylei.hxx |3 
 include/xmloff/txtstyli.hxx |3 
 include/xmloff/xmlnumi.hxx  |8 
 include/xmloff/xmlstyle.hxx |   17 
 reportdesign/source/filter/xml/xmlStyleImport.cxx   |   13 
 reportdesign/source/filter/xml/xmlStyleImport.hxx   |3 
 sc/source/filter/xml/xmlstyli.cxx   |   21 
 sc/source/filter/xml/xmlstyli.hxx   |7 
 sw/source/filter/xml/xmlfmt.cxx |   38 
 sw/source/uibase/config/StoredChapterNumbering.cxx  |3 
 xmloff/inc/PageMasterImportContext.hxx  |3 
 xmloff/inc/XMLChartStyleContext.hxx |3 
 xmloff/inc/XMLIndexBibliographyConfigurationContext.hxx |5 
 xmloff/inc/XMLLineNumberingImportContext.hxx|6 
 xmloff/source/chart/XMLChartStyleContext.cxx|6 
 xmloff/source/draw/XMLGraphicsDefaultStyle.cxx  |4 
 xmloff/source/draw/XMLShapePropertySetContext.cxx   |2 
 xmloff/source/draw/XMLShapeStyleContext.cxx |4 
 xmloff/source/draw/ximpstyl.cxx |   35 
 xmloff/source/style/PageMasterImportContext.cxx |4 
 xmloff/source/style/XMLFontStylesContext.cxx|   22 
 xmloff/source/style/XMLFontStylesContext_impl.hxx   |9 
 xmloff/source/style/prstylei.cxx|4 
 xmloff/source/style/xmlnumfi.cxx|4 
 xmloff/source/style/xmlnumi.cxx |  445 
+++---
 xmloff/source/style/xmlstyle.cxx|   71 -
 xmloff/source/table/XMLTableImport.cxx  |   10 
 xmloff/source/text/XMLFootnoteConfigurationImportContext.cxx|4 
 xmloff/source/text/XMLIndexBibliographyConfigurationContext.cxx |6 
 xmloff/source/text/XMLLineNumberingImportContext.cxx|6 
 xmloff/source/text/XMLTextMasterPageContext.cxx |4 
 xmloff/source/text/XMLTextShapeStyleContext.cxx |5 
 xmloff/source/text/txtstyli.cxx |4 
 39 files changed, 275 insertions(+), 533 deletions(-)

New commits:
commit f59334988a77eece1cae7d63e0df4320beebf384
Author: Noel Grandin 
AuthorDate: Sun Aug 30 10:22:09 2020 +0200
Commit: Noel Grandin 
CommitDate: Sun Aug 30 13:50:06 2020 +0200

use more fastparser in SvXMLStyleContext subclasses

Change-Id: I6a1596bdbfa4db128730a663fc590c9e5bfa249d
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101659
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/dbaccess/source/filter/xml/xmlStyleImport.cxx 
b/dbaccess/source/filter/xml/xmlStyleImport.cxx
index e75a1d57861f..46534bb233c7 100644
--- a/dbaccess/source/filter/xml/xmlStyleImport.cxx
+++ b/dbaccess/source/filter/xml/xmlStyleImport.cxx
@@ -41,10 +41,8 @@ using namespace xmloff::token;
 
 
 OTableStyleContext::OTableStyleContext( ODBFilter& rImport,
-sal_Int32 nElement,
-const Reference< XFastAttributeList > & xAttrList,
 SvXMLStylesContext& rStyles, XmlStyleFamily nFamily )
-:XMLPropStyleContext( rImport, nElement, xAttrList, rStyles, nFamily, 
false )
+:XMLPropStyleContext( rImport, rStyles, nFamily, false )
 ,pStyles(&rStyles)
 ,m_nNumberFormat(-1)
 {
@@ -204,8 +202,7 @@ SvXMLStyleContext 
*OTableStylesContext::CreateStyleStyleChildContext(
 case XmlStyleFamily::TABLE_TABLE:
 case XmlStyleFamily::TABLE_COLUMN:
 case XmlStyleFamily::TABLE_CELL:
-return new OTableStyleContext( GetOwnImport(), nElement,
-   xAttrList, *this, nFamily );
+return new OTableStyleContext( GetOwnImport(), *this, nFamily );
 break;
 default: break;
 }
diff --git a/dbaccess/source/filter/xml/xmlStyleImport.hxx 
b/dbaccess/source/filter/xml/xmlStyleImport.hxx
index 8f962fd42b71..ee8ec1524357 100644
--- a/dbaccess/source/filter/xml/xmlStyleImport.hxx
+++ b/dbaccess/source/filter/xml/xmlStyleImport.hxx
@@ -47,8 +47,7 @@ namespace dbaxml
 public:
 
 
-OTableStyleContext( ODBFilter& rImport, sal_Int32 nElement,
-const css::uno::Reference< css::xml::sax::XFastAttributeList > 
& xAttrLis

[Libreoffice-commits] core.git: helpcontent2

2020-08-30 Thread Olivier Hallot (via logerrit)
 helpcontent2 |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 8c65269a70b2d7d2323629204842f0ac751cf555
Author: Olivier Hallot 
AuthorDate: Sun Aug 30 06:08:58 2020 -0300
Commit: Gerrit Code Review 
CommitDate: Sun Aug 30 11:08:58 2020 +0200

Update git submodules

* Update helpcontent2 from branch 'master'
  to da7d4570411ec5324a68e4e3a671fde9f66355c8
  - Add contents for special cases of IIF function

Add example in Basic.

Change-Id: I9c38bd4a0744fccce19c1f88112301937806ae75
Reviewed-on: https://gerrit.libreoffice.org/c/help/+/101562
Tested-by: Jenkins
Reviewed-by: Olivier Hallot 

diff --git a/helpcontent2 b/helpcontent2
index 327d999641b5..da7d4570411e 16
--- a/helpcontent2
+++ b/helpcontent2
@@ -1 +1 @@
-Subproject commit 327d999641b54d40d8f939a09ab79f37b4a9fc32
+Subproject commit da7d4570411ec5324a68e4e3a671fde9f66355c8
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] help.git: source/text

2020-08-30 Thread Olivier Hallot (via logerrit)
 source/text/sbasic/shared/03090103.xhp |   23 +--
 1 file changed, 17 insertions(+), 6 deletions(-)

New commits:
commit da7d4570411ec5324a68e4e3a671fde9f66355c8
Author: Olivier Hallot 
AuthorDate: Fri Aug 28 15:35:52 2020 -0300
Commit: Olivier Hallot 
CommitDate: Sun Aug 30 11:08:58 2020 +0200

Add contents for special cases of IIF function

Add example in Basic.

Change-Id: I9c38bd4a0744fccce19c1f88112301937806ae75
Reviewed-on: https://gerrit.libreoffice.org/c/help/+/101562
Tested-by: Jenkins
Reviewed-by: Olivier Hallot 

diff --git a/source/text/sbasic/shared/03090103.xhp 
b/source/text/sbasic/shared/03090103.xhp
index 7b288f74e..07b6e453d 100644
--- a/source/text/sbasic/shared/03090103.xhp
+++ b/source/text/sbasic/shared/03090103.xhp
@@ -1,5 +1,4 @@
 
-
 
-
 
 
 
@@ -32,20 +30,33 @@
 
 IIf function
 
-IIf 
Function
+IIf Function
 Returns one of 
two possible function results, depending on the logical value of the evaluated 
expression.
 
-Syntax:
+
 
 IIf (Expression, 
ExpressionTrue, ExpressionFalse)
 
-Parameters:
+
 
 Expression: Any expression that you want to evaluate. If the 
expression evaluates to True, the function returns the result of 
ExpressionTrue, otherwise it returns the result of ExpressionFalse.
 
 ExpressionTrue, ExpressionFalse: Any expression, one of which 
will be returned as the function result, depending on the logical 
evaluation.
+IIf evaluates both 
ExpressionTrue and ExpressionFalse even 
if it returns only one of them. If one of the expressions results in error, the 
function returns the error. For example, do not use IIF to bypass a possible 
division by zero result.
 
 
+
+
+REM 
Returns the maximum of 3 values
+Function Max (A As Double, B As Double, C, As Double) As 
Double
+Max = IIf( A >= B, A, B)
+Max = IIf( C >= Max, C, Max)
+End Function
+REM Bad 
usage of function IIf
+Function Inverse(A As Double) As Double
+Inverse = IIf( A = 0, 0, 1/A )
+End Function
+
 
 
   If or Select Case statements
@@ -53,4 +64,4 @@
 
 
 
-
\ No newline at end of file
+
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: scaddins/source

2020-08-30 Thread Andrea Gelmini (via logerrit)
 scaddins/source/analysis/analysishelper.cxx |6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 6fc5b1c1f049971af3d9853085f3ef3c9e630b0b
Author: Andrea Gelmini 
AuthorDate: Sat Aug 29 19:24:28 2020 +0200
Commit: Julien Nabet 
CommitDate: Sun Aug 30 10:57:38 2020 +0200

Fix typo

Change-Id: I7fbf7d2c832b3e88b9ea82872c24450c33edc8aa
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/101649
Tested-by: Jenkins
Reviewed-by: Julien Nabet 

diff --git a/scaddins/source/analysis/analysishelper.cxx 
b/scaddins/source/analysis/analysishelper.cxx
index 2e799c9d1588..7cc6a90a0696 100644
--- a/scaddins/source/analysis/analysishelper.cxx
+++ b/scaddins/source/analysis/analysishelper.cxx
@@ -2266,7 +2266,7 @@ ConvertDataList::ConvertDataList()
 NEWD( "in", 3.9370078740157480E01,  CDC_Length ); // Inch  
 39,37007874015748031496062992126
 NEWD( "ft", 3.2808398950131234E00,  CDC_Length ); // Foot  
 3,2808398950131233595800524934383
 NEWD( "yd", 1.0936132983377078E00,  CDC_Length ); // Yard  
 1,0936132983377077865266841644794
-NEWDP( "ang",   1.E10,  CDC_Length ); // Angstroem
+NEWDP( "ang",   1.E10,  CDC_Length ); // Angstrom
 NEWD( "Pica",   2.8346456692913386E03,  CDC_Length ); // Pica Point 
(1/72 Inch)   2834,6456692913385826771653543307
 NEWD( "picapt", 2.8346456692913386E03,  CDC_Length ); // Pica Point 
(1/72 Inch)   2834,6456692913385826771653543307
 NEWD( "pica",   2.36220472441E02,   CDC_Length ); // pica (1/6 
Inch)
@@ -2357,7 +2357,7 @@ ConvertDataList::ConvertDataList()
 NEWD( "in3",6.1023744094732284E01,  CDC_Volume ); // *** Cubic Inch
 NEWD( "ft3",3.5314666721488590E-02, CDC_Volume ); // *** Cubic Foot
 NEWD( "yd3",1.3079506193143922E-03, CDC_Volume ); // *** Cubic Yard
-NEWDP( "ang3",  1.E27,  CDC_Volume ); // *** Cubic 
Angstroem
+NEWDP( "ang3",  1.E27,  CDC_Volume ); // *** Cubic 
Angstrom
 NEWD( "Pica3",  2.2776990435870636E07,  CDC_Volume ); // *** Cubic 
Pica Point (1/72 inch)
 NEWD( "picapt3",2.2776990435870636E07,  CDC_Volume ); // *** Cubic 
Pica Point (1/72 inch)
 NEWD( "pica3",  1.31811287245E04,   CDC_Volume ); // *** Cubic 
Pica (1/6 inch)
@@ -2383,7 +2383,7 @@ ConvertDataList::ConvertDataList()
 NEWD( "in2",1.550003162000E03,  CDC_Area ); // *** Square Inch
 NEWD( "ft2",1.0763910416709722E01,  CDC_Area ); // *** Square Foot
 NEWD( "yd2",1.1959900463010803E00,  CDC_Area ); // *** Square Yard
-NEWDP( "ang2",  1.E20,  CDC_Area ); // *** Square 
Angstroem
+NEWDP( "ang2",  1.E20,  CDC_Area ); // *** Square 
Angstrom
 NEWD( "Pica2",  8.0352160704321409E06,  CDC_Area ); // *** Square Pica 
Point (1/72 inch)
 NEWD( "picapt2",8.0352160704321409E06,  CDC_Area ); // *** Square Pica 
Point (1/72 inch)
 NEWD( "pica2",  5.58001116002232E04,CDC_Area ); // *** Square Pica 
(1/6 inch)
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits
diff --git a/winaccessibility/source/UAccCOM/AccValue.cxx 
b/winaccessibility/source/UAccCOM/AccValue.cxx
index b0b24650aa06..7c8f069b4d6c 100644
--- a/winaccessibility/source/UAccCOM/AccValue.cxx
+++ b/winaccessibility/source/UAccCOM/AccValue.cxx
@@ -173,16 +173,16 @@ COM_DECLSPEC_NOTHROW STDMETHODIMP 
CAccValue::get_maximumValue(VARIANT *maximumVa
 
 /**
* Get minimum value.
    * @param  mininumValue Variant that accepts minimum value.
* @return Result.
*/
-COM_DECLSPEC_NOTHROW STDMETHODIMP CAccValue::get_minimumValue(VARIANT 
*mininumValue)
+COM_DECLSPEC_NOTHROW STDMETHODIMP CAccValue::get_minimumValue(VARIANT 
*minimumValue)
 {
 SolarMutexGuard g;
 
 ENTER_PROTECTED_BLOCK
 
-if (mininumValue == nullptr)
+if (minimumValue == nullptr)
 return E_FAIL;
 if ( !pRXVal.is() )
 return E_FAIL;
@@ -190,7 +190,7 @@ COM_DECLSPEC_NOTHROW STDMETHODIMP 
CAccValue::get_minimumValue(VARIANT *mininumVa
 // Get Any type value from UNO.
 css::uno::Any  anyVal = GetXInterface()->getMinimumValue();
 // Convert Any to VARIANT.
-CMAccessible::ConvertAnyToVariant(anyVal, mininumValue);
+CMAccessible::ConvertAnyToVariant(anyVal, minimumValue);
 
 return S_OK;
 
@@ -173,16 +173,16 @@ COM_DECLSPEC_NOTHROW STDMETHODIMP 
 /**
* Get minimum value.
-   * @param  mininumValue Variant that accepts minimum value.
+   * @param  minimumValue Variant that accepts minimum value.
* @return Result.
*/